[llvm-commits] [llvm] r152359 - /llvm/trunk/include/llvm/CodeGen/Passes.h

Andrew Trick atrick at apple.com
Thu Mar 8 16:52:18 PST 2012


Author: atrick
Date: Thu Mar  8 18:52:17 2012
New Revision: 152359

URL: http://llvm.org/viewvc/llvm-project?rev=152359&view=rev
Log:
Added TargetPassConfig::enablePass

Modified:
    llvm/trunk/include/llvm/CodeGen/Passes.h

Modified: llvm/trunk/include/llvm/CodeGen/Passes.h
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/include/llvm/CodeGen/Passes.h?rev=152359&r1=152358&r2=152359&view=diff
==============================================================================
--- llvm/trunk/include/llvm/CodeGen/Passes.h (original)
+++ llvm/trunk/include/llvm/CodeGen/Passes.h Thu Mar  8 18:52:17 2012
@@ -101,7 +101,10 @@
   /// point where StadardID is expected, add TargetID in its place.
   void substitutePass(char &StandardID, char &TargetID);
 
-  /// Allow the target to disable a specific standard pass.
+  /// Allow the target to enable a specific standard pass by default.
+  void enablePass(char &ID) { substitutePass(ID, ID); }
+
+  /// Allow the target to disable a specific standard pass by default.
   void disablePass(char &ID) { substitutePass(ID, NoPassID); }
 
   /// Return the pass ssubtituted for StandardID by the target.





More information about the llvm-commits mailing list